{+--------------------------------------------------------------------------+
   Component:   Order Object definition for Late Customisation example
   Author:      Adrian Rye
 +--------------------------------------------------------------------------+}
unit uLateCustom_Order;

interface

uses
  // Delphi
  Windows, Messages, SysUtils, Classes, Contnrs;

type
//  TlcOrder = class(TObject)
  TlcOrder = class(TPersistent)
  private
    FFreight       : Double;
    FOrderNo       : Double;
    FCustNo        : Double;
    FAmountPaid    : Double;
    FTaxRate       : Double;
    FItemsTotal    : Double;
    FEmpNo         : Integer;
    FShipToAddr1   : string;
    FShipToCountry : string;
    FShipVIA       : string;
    FShipToAddr2   : string;
    FShipToZip     : string;
    FShipToContact : string;
    FShipToState   : string;
    FTerms         : string;
    FShipToCity    : string;
    FPaymentMethod : string;
    FPO            : string;
    FShipToPhone   : string;
    FShipDate      : TDateTime;
    FSaleDate      : TDateTime;
//  public
  published
    property OrderNo: Double       read FOrderNo       write FOrderNo;
    property CustNo: Double        read FCustNo        write FCustNo;
    property SaleDate: TDateTime   read FSaleDate      write FSaleDate;
    property ShipDate: TDateTime   read FShipDate      write FShipDate;
    property EmpNo: Integer        read FEmpNo         write FEmpNo;
    property ShipToContact: string read FShipToContact write FShipToContact;
    property ShipToAddr1: string   read FShipToAddr1   write FShipToAddr1;
    property ShipToAddr2: string   read FShipToAddr2   write FShipToAddr2;
    property ShipToCity: string    read FShipToCity    write FShipToCity;
    property ShipToState: string   read FShipToState   write FShipToState;
    property ShipToZip: string     read FShipToZip     write FShipToZip;
    property ShipToCountry: string read FShipToCountry write FShipToCountry;
    property ShipToPhone: string   read FShipToPhone   write FShipToPhone;
    property ShipVIA: string       read FShipVIA       write FShipVIA;
    property PO: string            read FPO            write FPO;
    property Terms: string         read FTerms         write FTerms;
    property PaymentMethod: string read FPaymentMethod write FPaymentMethod;
    property ItemsTotal: Double    read FItemsTotal    write FItemsTotal;
    property TaxRate: Double       read FTaxRate       write FTaxRate;
    property Freight: Double       read FFreight       write FFreight;
    property AmountPaid: Double    read FAmountPaid    write FAmountPaid;
  end;

  TlcOrderList = class(TObjectList)
  private
    function GetOrder(aIndex: Integer): TlcOrder;
    procedure SetOrder(aIndex: Integer; const aValue: TlcOrder);
  public
    property Order[aIndex: Integer]: TlcOrder read GetOrder write SetOrder; default;
    procedure FillList;
  end;

var
  OrderList : TlcOrderList;

implementation

uses
  // Delphi
  DB,
  // Late Custom
  uLateCustom_DM;



{ TlcOrderList }

procedure TlcOrderList.FillList;
  var
    newOrder : TlcOrder;
  begin
    Clear;
    with DMLateCustom do begin
      tblOrders.First;
      while not tblOrders.Eof do begin
        newOrder := TlcOrder.Create;
        newOrder.OrderNo       := tblOrdersOrderNo.Value;
        newOrder.CustNo        := tblOrdersCustNo.Value;
        newOrder.SaleDate      := tblOrdersSaleDate.Value;
        newOrder.ShipDate      := tblOrdersShipDate.Value;
        newOrder.EmpNo         := tblOrdersEmpNo.Value;
        newOrder.ShipToContact := tblOrdersShipToContact.Value;
        newOrder.ShipToAddr1   := tblOrdersShipToAddr1.Value;
        newOrder.ShipToCity    := tblOrdersShipToCity.Value;
        newOrder.ShipToState   := tblOrdersShipToState.Value;
        // ...et al
        Add(newOrder);
        tblOrders.Next;
      end;
    end;
  end;

function TlcOrderList.GetOrder(aIndex: Integer): TlcOrder;
  begin
    Result := TlcOrder(Items[aIndex]);
  end;

procedure TlcOrderList.SetOrder(aIndex: Integer; const aValue: TlcOrder);
  begin
    Items[aIndex] := aValue;
  end;

initialization
  begin
    OrderList := TlcOrderList.Create;
  end;

finalization
  begin
    OrderList.Free;
  end;


end.
